#
# spec file for package ghc-clash-prelude
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name clash-prelude
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.99.3
Release:        lp150.2.4
Summary:        CAES Language for Synchronous Hardware - Prelude library
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-constraints-devel
BuildRequires:  ghc-data-binary-ieee754-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-ghc-typelits-extra-devel
BuildRequires:  ghc-ghc-typelits-knownnat-devel
BuildRequires:  ghc-ghc-typelits-natnormalise-devel
BuildRequires:  ghc-half-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-reflection-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-singletons-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-doctest-devel
%endif

%description
CλaSH (pronounced ‘clash’) is a functional hardware description language that
borrows both its syntax and semantics from the functional programming language
Haskell. The CλaSH compiler transforms these high-level descriptions to
low-level synthesizable VHDL, Verilog, or SystemVerilog.

Features of CλaSH:

* Strongly typed, but with a very high degree of type inference, enabling both
safe and fast prototyping using concise descriptions.

* Interactive REPL: load your designs in an interpreter and easily test all
your component without needing to setup a test bench.

* Higher-order functions, with type inference, result in designs that are fully
parametric by default.

* Synchronous sequential circuit design based on streams of values, called
'Signal's, lead to natural descriptions of feedback loops.

* Support for multiple clock domains, with type safe clock domain crossing.

This package provides:

* Prelude library containing datatypes and functions for circuit design

To use the library:

* Import "Clash.Prelude"

* Alternatively, if you want to explicitly route clock and reset ports, for
more straightforward multi-clock designs, you can import the
"Clash.Explicit.Prelude" module. Note that you should not import
"Clash.Prelude" and "Clash.Explicit.Prelude" at the same time as they have
overlapping definitions.

A preliminary version of a tutorial can be found in "Clash.Tutorial", for a
general overview of the library you should however check out "Clash.Prelude".
Some circuit examples can be found in "Clash.Examples".

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc AUTHORS.md CHANGELOG.md README.md doc

%changelog
* Sun Jul 29 2018 psimons@suse.com
- Update clash-prelude to version 0.99.3.
  [#]# 0.99.3 *July 26th 2018*
  * Bundle and BitPack instances up to and including 62-tuples
  * Handle undefined writes to RAM properly
  * Handle undefined clock enables properly
* Tue Jul 10 2018 psimons@suse.com
- Add clash-prelude at version 0.99.2.
